@@ -1,9 +1,7 @@
 from pydantic import BaseModel, Field
 from typing import Literal, Union
 from typing_extensions import Annotated
-from py_linq import Enumerable
-
-from preprocess.ReliabilityDTOs import ReliabilityMethod
+from src.reliability.ReliabilityMethodsDTOs import ReliabilityMethod
 
 
 class ModuleBaseDTO(BaseModel):
@@ -22,4 +20,4 @@ class ReliabilityDTO(ModuleBaseDTO):
     methodData: ReliabilityMethod
 
 
-ModuleDTO = Annotated[Union[ReliabilityDTO, SamplingDTO], Field(discriminator='uqType')]
\ No newline at end of file
+ModuleDTO = Annotated[Union[ReliabilityDTO, SamplingDTO], Field(discriminator='uqType')]
